#!/bin/bash

my_exit() {
    exit $1
}

remove_support_user(){

    echo "Removing all the processes owned by [$s_user_support]" 
    # We need to kill all the processes owned by FortiSOAR Support user
    killall --wait --user $s_user_support 

    echo "Checking if [$s_user_support] exists in the system." 
    s_support_userid=$(id -u $s_user_support)

    flag_fortisoar_support_present=$?

    if [ $flag_fortisoar_support_present -ne 0 ]; then
        echo "user [$s_user_support] does not exist or already removed"
        my_exit 0
    fi

    echo "Deleting [$s_user_support] user" 
    userdel -r $s_user_support 
    if [ $? -ne 0 ]; then
        echo "Failed to remove user [$s_user_support]"
        my_exit 1
    fi
}

remove_sudoers_privileges(){
    # Remove the sudoers file for fortisoar_support user.
    echo "Removing sudoers entry for [$s_user_support] in $f_support_user_sudoers file."

    rm -f $f_support_user_sudoers
}

remove_fortisoar_auditd_rules(){
    
    echo "Removing audit rules for support user"

    # Removing audit rule for logging the 'execve' system calls performed by 'fortisoar_support' user. 
    # Remove lines with the specific patterns

    sed -i "/$s_fortisoar_support_user_audit_key/d" "$f_fortisoar_audit_rule"

    # Load audit rules after removing rules for fortisoar_support user. 
    augenrules --load
}

deny_ssh_login(){
    # Remove ssh allow entry for fortisoar_support user. 
    rm -rf $f_etc_sshd_config
    systemctl restart sshd
}

init(){
    s_user_support="fortisoar_support"

    s_fortisoar_support_user_audit_key="fortisoar-support-user-audit"

    f_etc_sshd_config="/etc/ssh/sshd_config.d/fortisoar-support-user-login.conf"
    f_support_user_sudoers="/etc/sudoers.d/fortisoar-support-user"
    f_fortisoar_audit_rule="/etc/audit/rules.d/fortisoar-audit-rule.rules"

}

main(){
    
    remove_sudoers_privileges
    deny_ssh_login
    remove_fortisoar_auditd_rules
    remove_support_user
    
}

init
main

